==> crm-commom-vo-1.1.9.25.release.jar: com/biz/crm/nebular/sfa/visitdealer/req/SfaVisitDealerDetailReqVo.java <==
package com.biz.crm.nebular.sfa.visitdealer.req;

import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.biz.crm.nebular.sfa.picture.req.SfaVisitPictureReqVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * 经销商拜访明细;请求vo
 *
 * @author lf
 * @date 2020-11-17 11:22:50
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "SfaVisitDealerDetailReqVo", description = "经销商拜访明细;")
public class SfaVisitDealerDetailReqVo extends CrmExtTenVo {

    @ApiModelProperty("ID集合")
    private List<String> ids;

    @ApiModelProperty("拜访计划编码;拜访计划编码")
    private String visitPlanCode;

    @ApiModelProperty("人员账号;人员账号")
    private String visitUserName;

    @ApiModelProperty("人员姓名;人员姓名")
    private String visitRealName;

    @ApiModelProperty("人员职位编码;人员职位编码")
    private String visitPosCode;

    @ApiModelProperty("人员职位名称;人员职位名称")
    private String visitPosName;

    @ApiModelProperty("人员所属组织编码;人员所属组织编码")
    private String visitOrgCode;

    @ApiModelProperty("人员所属组织名称;人员所属组织名称")
    private String visitOrgName;

    @ApiModelProperty("拜访日期;拜访日期yyyy-MM-dd")
    private String visitDate;

    @ApiModelProperty("拜访类型;拜访类型(临时拜访/计划拜访)")
    private String visitType;

    @ApiModelProperty("客户id;客户id")
    private String clientId;

    @ApiModelProperty("客户编码;协防客户编码")
    private String clientCode;

    @ApiModelProperty("客户名称;协访客户名称")
    private String clientName;

    @ApiModelProperty("客户类型;协访客户类型")
    private String clientType;

    @ApiModelProperty("客户电话 客户电话")
    private String clientPhone;

    @ApiModelProperty("客户地址;客户地址")
    private String clientAddress;

    @ApiModelProperty("状态;拜访状态")
    private String visitStatus;

    @ApiModelProperty("异常提交时间")
    private String exceptionTime;

    @ApiModelProperty("异常描述")
    private String exceptionDetail;

    @ApiModelProperty("拜访总结")
    private String visitSummary;

    @ApiModelProperty("进店时间")
    private String inStore;

    @ApiModelProperty("进店地址")
    private String inStoreAddress;

    @ApiModelProperty("进店经度")
    private BigDecimal inStoreLongitude;

    @ApiModelProperty("进店纬度")
    private BigDecimal inStoreLatitude;

    @ApiModelProperty("离店时间")
    private String outStore;

    @ApiModelProperty("离店地址")
    private String outStoreAddress;

    @ApiModelProperty("离店经度")
    private BigDecimal outStoreLongitude;

    @ApiModelProperty("离店纬度")
    private BigDecimal outStoreLatitude;

    @ApiModelProperty("提交开始时间")
    private String startTime;

    @ApiModelProperty("提交结束时间")
    private String endTime;

    @ApiModelProperty("拜访id")
    private String visitPlanId;

    @ApiModelProperty("照片")
    private List<SfaVisitPictureReqVo> photoList;

    @ApiModelProperty("拜访组织编码集合")
    private List<String> visitOrgCodeList;



}

==> crm-commom-vo-1.2.2.41.release.jar: com/biz/crm/nebular/sfa/visitdealer/req/SfaVisitDealerDetailReqVo.java <==
package com.biz.crm.nebular.sfa.visitdealer.req;

import com.biz.crm.nebular.mdm.CrmExtTenVo;
import com.biz.crm.nebular.sfa.picture.req.SfaVisitPictureReqVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.util.List;

/**
 * 经销商拜访明细;请求vo
 *
 * @author lf
 * @date 2020-11-17 11:22:50
 */
@Data
@Accessors(chain = true)
@EqualsAndHashCode(callSuper = false)
@ApiModel(value = "SfaVisitDealerDetailReqVo", description = "经销商拜访明细;")
public class SfaVisitDealerDetailReqVo extends CrmExtTenVo {

    @ApiModelProperty("ID集合")
    private List<String> ids;

    @ApiModelProperty("拜访计划编码;拜访计划编码")
    private String visitPlanCode;

    @ApiModelProperty("人员账号;人员账号")
    private String visitUserName;

    @ApiModelProperty("人员姓名;人员姓名")
    private String visitRealName;

    @ApiModelProperty("人员职位编码;人员职位编码")
    private String visitPosCode;

    @ApiModelProperty("人员职位名称;人员职位名称")
    private String visitPosName;

    @ApiModelProperty("人员所属组织编码;人员所属组织编码")
    private String visitOrgCode;

    @ApiModelProperty("人员所属组织名称;人员所属组织名称")
    private String visitOrgName;

    @ApiModelProperty("拜访日期;拜访日期yyyy-MM-dd")
    private String visitDate;

    @ApiModelProperty("拜访类型;拜访类型(临时拜访/计划拜访)")
    private String visitType;

    @ApiModelProperty("客户id;客户id")
    private String clientId;

    @ApiModelProperty("客户编码;协防客户编码")
    private String clientCode;

    @ApiModelProperty("客户名称;协访客户名称")
    private String clientName;

    @ApiModelProperty("客户类型;协访客户类型")
    private String clientType;

    @ApiModelProperty("客户电话 客户电话")
    private String clientPhone;

    @ApiModelProperty("客户地址;客户地址")
    private String clientAddress;

    @ApiModelProperty("状态;拜访状态")
    private String visitStatus;

    @ApiModelProperty("异常提交时间")
    private String exceptionTime;

    @ApiModelProperty("异常描述")
    private String exceptionDetail;

    @ApiModelProperty("拜访总结")
    private String visitSummary;

    @ApiModelProperty("进店时间")
    private String inStore;

    @ApiModelProperty("进店地址")
    private String inStoreAddress;

    @ApiModelProperty("进店经度")
    private BigDecimal inStoreLongitude;

    @ApiModelProperty("进店纬度")
    private BigDecimal inStoreLatitude;

    @ApiModelProperty("离店时间")
    private String outStore;

    @ApiModelProperty("离店地址")
    private String outStoreAddress;

    @ApiModelProperty("离店经度")
    private BigDecimal outStoreLongitude;

    @ApiModelProperty("离店纬度")
    private BigDecimal outStoreLatitude;

    @ApiModelProperty("提交开始时间")
    private String startTime;

    @ApiModelProperty("提交结束时间")
    private String endTime;

    @ApiModelProperty("拜访id")
    private String visitPlanId;

    @ApiModelProperty("照片")
    private List<SfaVisitPictureReqVo> photoList;

    @ApiModelProperty("拜访组织编码集合")
    private List<String> visitOrgCodeList;

    @ApiModelProperty("人员上级所属组织编码;人员上级所属组织编码")
    private String visitParentOrgCode;

    @ApiModelProperty("人员上级所属组织名称;人员上级所属组织名称")
    private String visitParentOrgName;



}
